Invocations is a collection of reusable `Invoke <http://pyinvoke.org>`_ tasks,
task collections and helper functions. Originally sourced from the Invoke
project's own project-management tasks file, they are now highly configurable
and used across a number of projects, with the intent to become a clearinghouse
for implementing common best practices.

Currently implemented topics include (but are not limited to):

- management of Sphinx documentation trees
- Python project release lifecycles
- dependency vendoring
- running test suites (unit, integration, coverage-oriented, etc)
- console utilities such as confirmation prompts

and more.
